@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::CampaignManagementService::AdGroup;
-# Copyright (C) 2010 Xerxes Tsang
+# Copyright (C) 2011 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,7 +19,7 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v6';
+    return 'https://adcenter.microsoft.com/v7';
 }
 
 our @_attributes = (qw/
@@ -73,13 +73,40 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
+our %_attribute_min_occurs = (
+    AdDistribution => 0,
+    BiddingModel => 0,
+    BroadMatchBid => 0,
+    CashBackInfo => 0,
+    ContentMatchBid => 0,
+    EndDate => 0,
+    ExactMatchBid => 0,
+    Id => 0,
+    LanguageAndRegion => 0,
+    Name => 0,
+    NegativeKeywords => 0,
+    NegativeSiteUrls => 0,
+    PhraseMatchBid => 0,
+    PricingModel => 0,
+    StartDate => 0,
+    Status => 0,
+);
+
+sub _attribute_min_occurs {
+    my ($self, $attribute) = @_;
+    if (exists $_attribute_min_occurs{$attribute}) {
+        return $_attribute_min_occurs{$attribute};
+    }
+    return $self->SUPER::_attribute_min_occurs($attribute);
+}
+
+__PACKAGE__->mk_accessors(@_attributes);
 
 1;
 
 =head1 SYNOPSIS
 
-See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for documentation of the various data objects.
+See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.
 
 =cut
 
