@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::CustomerBillingService;
-# Copyright (C) 2010 Xerxes Tsang
+# Copyright (C) 2011 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -101,7 +101,7 @@ sub _request_headers_expanded {
 }
 
 our $_response_headers = [
-    { name => 'TrackingId', type => 'string', namespace => 'https://adapi.microsoft.com' }
+    { name => 'TrackingId', type => 'string', namespace => 'https://adcenter.microsoft.com/api/customerbilling' }
 ];
 
 our $_response_headers_expanded = {
@@ -440,7 +440,6 @@ sub _array_types {
 }
 
 __PACKAGE__->mk_accessors(qw/
-    EndPoint
     ApplicationToken
     DeveloperToken
     Password
