@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::DestinationUrlPerformanceReportFilter;
-# Copyright (C) 2010 Xerxes Tsang
+# Copyright (C) 2011 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,11 +19,12 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v6';
+    return 'https://adcenter.microsoft.com/v7';
 }
 
 our @_attributes = (qw/
     AdDistribution
+    DeviceType
     LanguageAndRegion
 /);
 
@@ -34,6 +35,7 @@ sub _attributes {
 
 our %_attribute_type = (
     AdDistribution => 'AdDistributionReportFilter',
+    DeviceType => 'DeviceTypeReportFilter',
     LanguageAndRegion => 'LanguageAndRegionReportFilter',
 );
 
@@ -45,7 +47,21 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
+our %_attribute_min_occurs = (
+    AdDistribution => 0,
+    DeviceType => 0,
+    LanguageAndRegion => 0,
+);
+
+sub _attribute_min_occurs {
+    my ($self, $attribute) = @_;
+    if (exists $_attribute_min_occurs{$attribute}) {
+        return $_attribute_min_occurs{$attribute};
+    }
+    return $self->SUPER::_attribute_min_occurs($attribute);
+}
+
+__PACKAGE__->mk_accessors(@_attributes);
 
 1;
 
@@ -65,6 +81,10 @@ Creates a new instance
 
 Gets/sets AdDistribution (AdDistributionReportFilter)
 
+=head2 DeviceType
+
+Gets/sets DeviceType (DeviceTypeReportFilter)
+
 =head2 LanguageAndRegion
 
 Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
