@@ -1,5 +1,5 @@
 package Microsoft::AdCenter::ReportingService::ReportTime;
-# Copyright (C) 2010 Xerxes Tsang
+# Copyright (C) 2011 Xerxes Tsang
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of Perl Artistic License.
 
@@ -19,13 +19,12 @@ sub _type_name {
 }
 
 sub _namespace_uri {
-    return 'https://adcenter.microsoft.com/v6';
+    return 'https://adcenter.microsoft.com/v7';
 }
 
 our @_attributes = (qw/
     CustomDateRangeEnd
     CustomDateRangeStart
-    CustomDates
     PredefinedTime
 /);
 
@@ -37,7 +36,6 @@ sub _attributes {
 our %_attribute_type = (
     CustomDateRangeEnd => 'Date',
     CustomDateRangeStart => 'Date',
-    CustomDates => 'ArrayOfDate',
     PredefinedTime => 'ReportTimePeriod',
 );
 
@@ -49,13 +47,27 @@ sub _attribute_type {
     return $self->SUPER::_attribute_type($attribute);
 }
 
-__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);
+our %_attribute_min_occurs = (
+    CustomDateRangeEnd => 0,
+    CustomDateRangeStart => 0,
+    PredefinedTime => 0,
+);
+
+sub _attribute_min_occurs {
+    my ($self, $attribute) = @_;
+    if (exists $_attribute_min_occurs{$attribute}) {
+        return $_attribute_min_occurs{$attribute};
+    }
+    return $self->SUPER::_attribute_min_occurs($attribute);
+}
+
+__PACKAGE__->mk_accessors(@_attributes);
 
 1;
 
 =head1 SYNOPSIS
 
-See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for documentation of the various data objects.
+See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.
 
 =cut
 
@@ -73,10 +85,6 @@ Gets/sets CustomDateRangeEnd (Date)
 
 Gets/sets CustomDateRangeStart (Date)
 
-=head2 CustomDates
-
-Gets/sets CustomDates (ArrayOfDate)
-
 =head2 PredefinedTime
 
 Gets/sets PredefinedTime (ReportTimePeriod)
