@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::ReportingService::Test::AdPerformanceReportFilter;
+# Copyright (C) 2011 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -9,10 +12,11 @@ use Test::More;
 use Microsoft::AdCenter::ReportingService;
 use Microsoft::AdCenter::ReportingService::AdPerformanceReportFilter;
 
-sub test_can_create_ad_performance_report_filter_and_set_all_fields : Test(4) {
+sub test_can_create_ad_performance_report_filter_and_set_all_fields : Test(5) {
     my $ad_performance_report_filter = Microsoft::AdCenter::ReportingService::AdPerformanceReportFilter->new
         ->AdDistribution('ad distribution')
         ->AdType('ad type')
+        ->DeviceType('device type')
         ->LanguageAndRegion('language and region')
     ;
 
@@ -20,6 +24,7 @@ sub test_can_create_ad_performance_report_filter_and_set_all_fields : Test(4) {
 
     is($ad_performance_report_filter->AdDistribution, 'ad distribution', 'can get ad distribution');
     is($ad_performance_report_filter->AdType, 'ad type', 'can get ad type');
+    is($ad_performance_report_filter->DeviceType, 'device type', 'can get device type');
     is($ad_performance_report_filter->LanguageAndRegion, 'language and region', 'can get language and region');
 };
 
